Class: Aws::Kendra::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Kendra::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kendra/client.rb
Overview
An API client for Kendra. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Kendra::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_entities_to_experience(params = {}) ⇒ Types::AssociateEntitiesToExperienceResponse
Grants users or groups in your IAM Identity Center identity source access to your Amazon Kendra experience.
-
#associate_personas_to_entities(params = {}) ⇒ Types::AssociatePersonasToEntitiesResponse
Defines the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience.
-
#batch_delete_document(params = {}) ⇒ Types::BatchDeleteDocumentResponse
Removes one or more documents from an index.
-
#batch_delete_featured_results_set(params = {}) ⇒ Types::BatchDeleteFeaturedResultsSetResponse
Removes one or more sets of featured results.
-
#batch_get_document_status(params = {}) ⇒ Types::BatchGetDocumentStatusResponse
Returns the indexing status for one or more documents submitted with the [ BatchPutDocument] API.
-
#batch_put_document(params = {}) ⇒ Types::BatchPutDocumentResponse
Adds one or more documents to an index.
-
#clear_query_suggestions(params = {}) ⇒ Struct
Clears existing query suggestions from an index.
-
#create_access_control_configuration(params = {}) ⇒ Types::CreateAccessControlConfigurationResponse
Creates an access configuration for your documents.
-
#create_data_source(params = {}) ⇒ Types::CreateDataSourceResponse
Creates a data source connector that you want to use with an Amazon Kendra index.
-
#create_experience(params = {}) ⇒ Types::CreateExperienceResponse
Creates an Amazon Kendra experience such as a search application.
-
#create_faq(params = {}) ⇒ Types::CreateFaqResponse
Creates a set of frequently ask questions (FAQs) using a specified FAQ file stored in an Amazon S3 bucket.
-
#create_featured_results_set(params = {}) ⇒ Types::CreateFeaturedResultsSetResponse
Creates a set of featured results to display at the top of the search results page.
-
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an Amazon Kendra index.
-
#create_query_suggestions_block_list(params = {}) ⇒ Types::CreateQuerySuggestionsBlockListResponse
Creates a block list to exlcude certain queries from suggestions.
-
#create_thesaurus(params = {}) ⇒ Types::CreateThesaurusResponse
Creates a thesaurus for an index.
-
#delete_access_control_configuration(params = {}) ⇒ Struct
Deletes an access control configuration that you created for your documents in an index.
-
#delete_data_source(params = {}) ⇒ Struct
Deletes an Amazon Kendra data source connector.
-
#delete_experience(params = {}) ⇒ Struct
Deletes your Amazon Kendra experience such as a search application.
-
#delete_faq(params = {}) ⇒ Struct
Removes a FAQ from an index.
-
#delete_index(params = {}) ⇒ Struct
Deletes an Amazon Kendra index.
-
#delete_principal_mapping(params = {}) ⇒ Struct
Deletes a group so that all users that belong to the group can no longer access documents only available to that group.
-
#delete_query_suggestions_block_list(params = {}) ⇒ Struct
Deletes a block list used for query suggestions for an index.
-
#delete_thesaurus(params = {}) ⇒ Struct
Deletes an Amazon Kendra thesaurus.
-
#describe_access_control_configuration(params = {}) ⇒ Types::DescribeAccessControlConfigurationResponse
Gets information about an access control configuration that you created for your documents in an index.
-
#describe_data_source(params = {}) ⇒ Types::DescribeDataSourceResponse
Gets information about an Amazon Kendra data source connector.
-
#describe_experience(params = {}) ⇒ Types::DescribeExperienceResponse
Gets information about your Amazon Kendra experience such as a search application.
-
#describe_faq(params = {}) ⇒ Types::DescribeFaqResponse
Gets information about a FAQ.
-
#describe_featured_results_set(params = {}) ⇒ Types::DescribeFeaturedResultsSetResponse
Gets information about a set of featured results.
-
#describe_index(params = {}) ⇒ Types::DescribeIndexResponse
Gets information about an Amazon Kendra index.
-
#describe_principal_mapping(params = {}) ⇒ Types::DescribePrincipalMappingResponse
Describes the processing of ‘PUT` and `DELETE` actions for mapping users to their groups.
-
#describe_query_suggestions_block_list(params = {}) ⇒ Types::DescribeQuerySuggestionsBlockListResponse
Gets information about a block list used for query suggestions for an index.
-
#describe_query_suggestions_config(params = {}) ⇒ Types::DescribeQuerySuggestionsConfigResponse
Gets information on the settings of query suggestions for an index.
-
#describe_thesaurus(params = {}) ⇒ Types::DescribeThesaurusResponse
Gets information about an Amazon Kendra thesaurus.
-
#disassociate_entities_from_experience(params = {}) ⇒ Types::DisassociateEntitiesFromExperienceResponse
Prevents users or groups in your IAM Identity Center identity source from accessing your Amazon Kendra experience.
-
#disassociate_personas_from_entities(params = {}) ⇒ Types::DisassociatePersonasFromEntitiesResponse
Removes the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience.
-
#get_query_suggestions(params = {}) ⇒ Types::GetQuerySuggestionsResponse
Fetches the queries that are suggested to your users.
-
#get_snapshots(params = {}) ⇒ Types::GetSnapshotsResponse
Retrieves search metrics data.
-
#list_access_control_configurations(params = {}) ⇒ Types::ListAccessControlConfigurationsResponse
Lists one or more access control configurations for an index.
-
#list_data_source_sync_jobs(params = {}) ⇒ Types::ListDataSourceSyncJobsResponse
Gets statistics about synchronizing a data source connector.
-
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists the data source connectors that you have created.
-
#list_entity_personas(params = {}) ⇒ Types::ListEntityPersonasResponse
Lists specific permissions of users and groups with access to your Amazon Kendra experience.
-
#list_experience_entities(params = {}) ⇒ Types::ListExperienceEntitiesResponse
Lists users or groups in your IAM Identity Center identity source that are granted access to your Amazon Kendra experience.
-
#list_experiences(params = {}) ⇒ Types::ListExperiencesResponse
Lists one or more Amazon Kendra experiences.
-
#list_faqs(params = {}) ⇒ Types::ListFaqsResponse
Gets a list of FAQs associated with an index.
-
#list_featured_results_sets(params = {}) ⇒ Types::ListFeaturedResultsSetsResponse
Lists all your sets of featured results for a given index.
-
#list_groups_older_than_ordering_id(params = {}) ⇒ Types::ListGroupsOlderThanOrderingIdResponse
Provides a list of groups that are mapped to users before a given ordering or timestamp identifier.
-
#list_indices(params = {}) ⇒ Types::ListIndicesResponse
Lists the Amazon Kendra indexes that you created.
-
#list_query_suggestions_block_lists(params = {}) ⇒ Types::ListQuerySuggestionsBlockListsResponse
Lists the block lists used for query suggestions for an index.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags associated with a resource.
-
#list_thesauri(params = {}) ⇒ Types::ListThesauriResponse
Lists the thesauri for an index.
-
#put_principal_mapping(params = {}) ⇒ Struct
Maps users to their groups so that you only need to provide the user ID when you issue the query.
-
#query(params = {}) ⇒ Types::QueryResult
Searches an index given an input query.
-
#retrieve(params = {}) ⇒ Types::RetrieveResult
Retrieves relevant passages or text excerpts given an input query.
-
#start_data_source_sync_job(params = {}) ⇒ Types::StartDataSourceSyncJobResponse
Starts a synchronization job for a data source connector.
-
#stop_data_source_sync_job(params = {}) ⇒ Struct
Stops a synchronization job that is currently running.
-
#submit_feedback(params = {}) ⇒ Struct
Enables you to provide feedback to Amazon Kendra to improve the performance of your index.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tag to the specified index, FAQ, data source, or other resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from an index, FAQ, data source, or other resource.
-
#update_access_control_configuration(params = {}) ⇒ Struct
Updates an access control configuration for your documents in an index.
-
#update_data_source(params = {}) ⇒ Struct
Updates an Amazon Kendra data source connector.
-
#update_experience(params = {}) ⇒ Struct
Updates your Amazon Kendra experience such as a search application.
-
#update_featured_results_set(params = {}) ⇒ Types::UpdateFeaturedResultsSetResponse
Updates a set of featured results.
-
#update_index(params = {}) ⇒ Struct
Updates an Amazon Kendra index.
-
#update_query_suggestions_block_list(params = {}) ⇒ Struct
Updates a block list used for query suggestions for an index.
-
#update_query_suggestions_config(params = {}) ⇒ Struct
Updates the settings of query suggestions for an index.
-
#update_thesaurus(params = {}) ⇒ Struct
Updates a thesaurus for an index.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-kendra/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7501 7502 7503 |
# File 'lib/aws-sdk-kendra/client.rb', line 7501 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7504 7505 7506 |
# File 'lib/aws-sdk-kendra/client.rb', line 7504 def errors_module Errors end |
Instance Method Details
#associate_entities_to_experience(params = {}) ⇒ Types::AssociateEntitiesToExperienceResponse
Grants users or groups in your IAM Identity Center identity source access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
530 531 532 533 |
# File 'lib/aws-sdk-kendra/client.rb', line 530 def associate_entities_to_experience(params = {}, = {}) req = build_request(:associate_entities_to_experience, params) req.send_request() end |
#associate_personas_to_entities(params = {}) ⇒ Types::AssociatePersonasToEntitiesResponse
Defines the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
589 590 591 592 |
# File 'lib/aws-sdk-kendra/client.rb', line 589 def associate_personas_to_entities(params = {}, = {}) req = build_request(:associate_personas_to_entities, params) req.send_request() end |
#batch_delete_document(params = {}) ⇒ Types::BatchDeleteDocumentResponse
Removes one or more documents from an index. The documents must have been added with the ‘BatchPutDocument` API.
The documents are deleted asynchronously. You can see the progress of the deletion by using Amazon Web Services CloudWatch. Any error messages related to the processing of the batch are sent to your Amazon Web Services CloudWatch log. You can also use the ‘BatchGetDocumentStatus` API to monitor the progress of deleting your documents.
Deleting documents from an index using ‘BatchDeleteDocument` could take up to an hour or more, depending on the number of documents you want to delete.
644 645 646 647 |
# File 'lib/aws-sdk-kendra/client.rb', line 644 def batch_delete_document(params = {}, = {}) req = build_request(:batch_delete_document, params) req.send_request() end |
#batch_delete_featured_results_set(params = {}) ⇒ Types::BatchDeleteFeaturedResultsSetResponse
Removes one or more sets of featured results. Features results are placed above all other results for certain queries. If there’s an exact match of a query, then one or more specific documents are featured in the search results.
682 683 684 685 |
# File 'lib/aws-sdk-kendra/client.rb', line 682 def batch_delete_featured_results_set(params = {}, = {}) req = build_request(:batch_delete_featured_results_set, params) req.send_request() end |
#batch_get_document_status(params = {}) ⇒ Types::BatchGetDocumentStatusResponse
Returns the indexing status for one or more documents submitted with the [ BatchPutDocument] API.
When you use the ‘BatchPutDocument` API, documents are indexed asynchronously. You can use the `BatchGetDocumentStatus` API to get the current status of a list of documents so that you can determine if they have been successfully indexed.
You can also use the ‘BatchGetDocumentStatus` API to check the status of the [ BatchDeleteDocument] API. When a document is deleted from the index, Amazon Kendra returns `NOT_FOUND` as the status.
[1]: docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html [2]: docs.aws.amazon.com/kendra/latest/dg/API_BatchDeleteDocument.html
761 762 763 764 |
# File 'lib/aws-sdk-kendra/client.rb', line 761 def batch_get_document_status(params = {}, = {}) req = build_request(:batch_get_document_status, params) req.send_request() end |
#batch_put_document(params = {}) ⇒ Types::BatchPutDocumentResponse
Adds one or more documents to an index.
The ‘BatchPutDocument` API enables you to ingest inline documents or a set of documents stored in an Amazon S3 bucket. Use this API to ingest your text and unstructured text into an index, add custom attributes to the documents, and to attach an access control list to the documents added to the index.
The documents are indexed asynchronously. You can see the progress of the batch using Amazon Web Services CloudWatch. Any error messages related to processing the batch are sent to your Amazon Web Services CloudWatch log. You can also use the ‘BatchGetDocumentStatus` API to monitor the progress of indexing your documents.
For an example of ingesting inline documents using Python and Java SDKs, see [Adding files directly to an index].
[1]: docs.aws.amazon.com/kendra/latest/dg/in-adding-binary-doc.html
952 953 954 955 |
# File 'lib/aws-sdk-kendra/client.rb', line 952 def batch_put_document(params = {}, = {}) req = build_request(:batch_put_document, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 |
# File 'lib/aws-sdk-kendra/client.rb', line 7474 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Kendra') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kendra' context[:gem_version] = '1.115.0' Seahorse::Client::Request.new(handlers, context) end |
#clear_query_suggestions(params = {}) ⇒ Struct
Clears existing query suggestions from an index.
This deletes existing suggestions only, not the queries in the query log. After you clear suggestions, Amazon Kendra learns new suggestions based on new queries added to the query log from the time you cleared suggestions. If you do not see any new suggestions, then please allow Amazon Kendra to collect enough queries to learn new suggestions.
‘ClearQuerySuggestions` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
983 984 985 986 |
# File 'lib/aws-sdk-kendra/client.rb', line 983 def clear_query_suggestions(params = {}, = {}) req = build_request(:clear_query_suggestions, params) req.send_request() end |
#create_access_control_configuration(params = {}) ⇒ Types::CreateAccessControlConfigurationResponse
Creates an access configuration for your documents. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
You can use this to re-configure your existing document level access control without indexing all of your documents again. For example, your index contains top-secret company documents that only certain employees or users should access. One of these users leaves the company or switches to a team that should be blocked from accessing top-secret documents. The user still has access to top-secret documents because the user had access when your documents were previously indexed. You can create a specific access control configuration for the user with deny access. You can later update the access control configuration to allow access if the user returns to the company and re-joins the ‘top-secret’ team. You can re-configure access control for your documents as circumstances change.
To apply your access control configuration to certain documents, you call the [BatchPutDocument] API with the ‘AccessControlConfigurationId` included in the [Document] object. If you use an S3 bucket as a data source, you update the `.metadata.json` with the `AccessControlConfigurationId` and synchronize your data source. Amazon Kendra currently only supports access control configuration for S3 data sources and documents indexed using the `BatchPutDocument` API.
You can’t configure access control using ‘CreateAccessControlConfiguration` for an Amazon Kendra Gen AI Enterprise Edition index. Amazon Kendra will return a `ValidationException` error for a `Gen_AI_ENTERPRISE_EDITION` index.
[1]: docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html [2]: docs.aws.amazon.com/kendra/latest/dg/API_Document.html
1099 1100 1101 1102 |
# File 'lib/aws-sdk-kendra/client.rb', line 1099 def create_access_control_configuration(params = {}, = {}) req = build_request(:create_access_control_configuration, params) req.send_request() end |
#create_data_source(params = {}) ⇒ Types::CreateDataSourceResponse
Creates a data source connector that you want to use with an Amazon Kendra index.
You specify a name, data source connector type and description for your data source. You also specify configuration information for the data source connector.
‘CreateDataSource` is a synchronous operation. The operation returns 200 if the data source was successfully created. Otherwise, an exception is raised.
For an example of creating an index and data source using the Python SDK, see [Getting started with Python SDK]. For an example of creating an index and data source using the Java SDK, see [Getting started with Java SDK].
[1]: docs.aws.amazon.com/kendra/latest/dg/gs-python.html [2]: docs.aws.amazon.com/kendra/latest/dg/gs-java.html
1944 1945 1946 1947 |
# File 'lib/aws-sdk-kendra/client.rb', line 1944 def create_data_source(params = {}, = {}) req = build_request(:create_data_source, params) req.send_request() end |
#create_experience(params = {}) ⇒ Types::CreateExperienceResponse
Creates an Amazon Kendra experience such as a search application. For more information on creating a search application experience, including using the Python and Java SDKs, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
2025 2026 2027 2028 |
# File 'lib/aws-sdk-kendra/client.rb', line 2025 def create_experience(params = {}, = {}) req = build_request(:create_experience, params) req.send_request() end |
#create_faq(params = {}) ⇒ Types::CreateFaqResponse
Creates a set of frequently ask questions (FAQs) using a specified FAQ file stored in an Amazon S3 bucket.
Adding FAQs to an index is an asynchronous operation.
For an example of adding an FAQ to an index using Python and Java SDKs, see [Using your FAQ file].
[1]: docs.aws.amazon.com/kendra/latest/dg/in-creating-faq.html#using-faq-file
2136 2137 2138 2139 |
# File 'lib/aws-sdk-kendra/client.rb', line 2136 def create_faq(params = {}, = {}) req = build_request(:create_faq, params) req.send_request() end |
#create_featured_results_set(params = {}) ⇒ Types::CreateFeaturedResultsSetResponse
Creates a set of featured results to display at the top of the search results page. Featured results are placed above all other results for certain queries. You map specific queries to specific documents for featuring in the results. If a query contains an exact match, then one or more specific documents are featured in the search results.
You can create up to 50 sets of featured results per index. You can request to increase this limit by contacting [Support].
2249 2250 2251 2252 |
# File 'lib/aws-sdk-kendra/client.rb', line 2249 def create_featured_results_set(params = {}, = {}) req = build_request(:create_featured_results_set, params) req.send_request() end |
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an Amazon Kendra index. Index creation is an asynchronous API. To determine if index creation has completed, check the ‘Status` field returned from a call to `DescribeIndex`. The `Status` field is set to `ACTIVE` when the index is ready to use.
Once the index is active, you can index your documents using the ‘BatchPutDocument` API or using one of the supported [data sources].
For an example of creating an index and data source using the Python SDK, see [Getting started with Python SDK]. For an example of creating an index and data source using the Java SDK, see [Getting started with Java SDK].
[1]: docs.aws.amazon.com/kendra/latest/dg/data-sources.html [2]: docs.aws.amazon.com/kendra/latest/dg/gs-python.html [3]: docs.aws.amazon.com/kendra/latest/dg/gs-java.html
2419 2420 2421 2422 |
# File 'lib/aws-sdk-kendra/client.rb', line 2419 def create_index(params = {}, = {}) req = build_request(:create_index, params) req.send_request() end |
#create_query_suggestions_block_list(params = {}) ⇒ Types::CreateQuerySuggestionsBlockListResponse
Creates a block list to exlcude certain queries from suggestions.
Any query that contains words or phrases specified in the block list is blocked or filtered out from being shown as a suggestion.
You need to provide the file location of your block list text file in your S3 bucket. In your text file, enter each block word or phrase on a separate line.
For information on the current quota limits for block lists, see [Quotas for Amazon Kendra].
‘CreateQuerySuggestionsBlockList` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
For an example of creating a block list for query suggestions using the Python SDK, see [Query suggestions block list].
[1]: docs.aws.amazon.com/kendra/latest/dg/quotas.html [2]: docs.aws.amazon.com/kendra/latest/dg/query-suggestions.html#query-suggestions-blocklist
2529 2530 2531 2532 |
# File 'lib/aws-sdk-kendra/client.rb', line 2529 def create_query_suggestions_block_list(params = {}, = {}) req = build_request(:create_query_suggestions_block_list, params) req.send_request() end |
#create_thesaurus(params = {}) ⇒ Types::CreateThesaurusResponse
Creates a thesaurus for an index. The thesaurus contains a list of synonyms in Solr format.
For an example of adding a thesaurus file to an index, see [Adding custom synonyms to an index].
[1]: docs.aws.amazon.com/kendra/latest/dg/index-synonyms-adding-thesaurus-file.html
2611 2612 2613 2614 |
# File 'lib/aws-sdk-kendra/client.rb', line 2611 def create_thesaurus(params = {}, = {}) req = build_request(:create_thesaurus, params) req.send_request() end |
#delete_access_control_configuration(params = {}) ⇒ Struct
Deletes an access control configuration that you created for your documents in an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
2641 2642 2643 2644 |
# File 'lib/aws-sdk-kendra/client.rb', line 2641 def delete_access_control_configuration(params = {}, = {}) req = build_request(:delete_access_control_configuration, params) req.send_request() end |
#delete_data_source(params = {}) ⇒ Struct
Deletes an Amazon Kendra data source connector. An exception is not thrown if the data source is already being deleted. While the data source is being deleted, the ‘Status` field returned by a call to the `DescribeDataSource` API is set to `DELETING`. For more information, see [Deleting Data Sources].
Deleting an entire data source or re-syncing your index after deleting specific documents from a data source could take up to an hour or more, depending on the number of documents you want to delete.
[1]: docs.aws.amazon.com/kendra/latest/dg/delete-data-source.html
2679 2680 2681 2682 |
# File 'lib/aws-sdk-kendra/client.rb', line 2679 def delete_data_source(params = {}, = {}) req = build_request(:delete_data_source, params) req.send_request() end |
#delete_experience(params = {}) ⇒ Struct
Deletes your Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
2711 2712 2713 2714 |
# File 'lib/aws-sdk-kendra/client.rb', line 2711 def delete_experience(params = {}, = {}) req = build_request(:delete_experience, params) req.send_request() end |
#delete_faq(params = {}) ⇒ Struct
Removes a FAQ from an index.
2737 2738 2739 2740 |
# File 'lib/aws-sdk-kendra/client.rb', line 2737 def delete_faq(params = {}, = {}) req = build_request(:delete_faq, params) req.send_request() end |
#delete_index(params = {}) ⇒ Struct
Deletes an Amazon Kendra index. An exception is not thrown if the index is already being deleted. While the index is being deleted, the ‘Status` field returned by a call to the `DescribeIndex` API is set to `DELETING`.
2762 2763 2764 2765 |
# File 'lib/aws-sdk-kendra/client.rb', line 2762 def delete_index(params = {}, = {}) req = build_request(:delete_index, params) req.send_request() end |
#delete_principal_mapping(params = {}) ⇒ Struct
Deletes a group so that all users that belong to the group can no longer access documents only available to that group.
For example, after deleting the group “Summer Interns”, all interns who belonged to that group no longer see intern-only documents in their search results.
If you want to delete or replace users or sub groups of a group, you need to use the ‘PutPrincipalMapping` operation. For example, if a user in the group “Engineering” leaves the engineering team and another user takes their place, you provide an updated list of users or sub groups that belong to the “Engineering” group when calling `PutPrincipalMapping`. You can update your internal list of users or sub groups and input this list when calling `PutPrincipalMapping`.
‘DeletePrincipalMapping` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
2836 2837 2838 2839 |
# File 'lib/aws-sdk-kendra/client.rb', line 2836 def delete_principal_mapping(params = {}, = {}) req = build_request(:delete_principal_mapping, params) req.send_request() end |
#delete_query_suggestions_block_list(params = {}) ⇒ Struct
Deletes a block list used for query suggestions for an index.
A deleted block list might not take effect right away. Amazon Kendra needs to refresh the entire suggestions list to add back the queries that were previously blocked.
‘DeleteQuerySuggestionsBlockList` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
2869 2870 2871 2872 |
# File 'lib/aws-sdk-kendra/client.rb', line 2869 def delete_query_suggestions_block_list(params = {}, = {}) req = build_request(:delete_query_suggestions_block_list, params) req.send_request() end |
#delete_thesaurus(params = {}) ⇒ Struct
Deletes an Amazon Kendra thesaurus.
2895 2896 2897 2898 |
# File 'lib/aws-sdk-kendra/client.rb', line 2895 def delete_thesaurus(params = {}, = {}) req = build_request(:delete_thesaurus, params) req.send_request() end |
#describe_access_control_configuration(params = {}) ⇒ Types::DescribeAccessControlConfigurationResponse
Gets information about an access control configuration that you created for your documents in an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
2949 2950 2951 2952 |
# File 'lib/aws-sdk-kendra/client.rb', line 2949 def describe_access_control_configuration(params = {}, = {}) req = build_request(:describe_access_control_configuration, params) req.send_request() end |
#describe_data_source(params = {}) ⇒ Types::DescribeDataSourceResponse
Gets information about an Amazon Kendra data source connector.
3502 3503 3504 3505 |
# File 'lib/aws-sdk-kendra/client.rb', line 3502 def describe_data_source(params = {}, = {}) req = build_request(:describe_data_source, params) req.send_request() end |
#describe_experience(params = {}) ⇒ Types::DescribeExperienceResponse
Gets information about your Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
3568 3569 3570 3571 |
# File 'lib/aws-sdk-kendra/client.rb', line 3568 def describe_experience(params = {}, = {}) req = build_request(:describe_experience, params) req.send_request() end |
#describe_faq(params = {}) ⇒ Types::DescribeFaqResponse
Gets information about a FAQ.
3623 3624 3625 3626 |
# File 'lib/aws-sdk-kendra/client.rb', line 3623 def describe_faq(params = {}, = {}) req = build_request(:describe_faq, params) req.send_request() end |
#describe_featured_results_set(params = {}) ⇒ Types::DescribeFeaturedResultsSetResponse
Gets information about a set of featured results. Features results are placed above all other results for certain queries. If there’s an exact match of a query, then one or more specific documents are featured in the search results.
3680 3681 3682 3683 |
# File 'lib/aws-sdk-kendra/client.rb', line 3680 def describe_featured_results_set(params = {}, = {}) req = build_request(:describe_featured_results_set, params) req.send_request() end |
#describe_index(params = {}) ⇒ Types::DescribeIndexResponse
Gets information about an Amazon Kendra index.
3762 3763 3764 3765 |
# File 'lib/aws-sdk-kendra/client.rb', line 3762 def describe_index(params = {}, = {}) req = build_request(:describe_index, params) req.send_request() end |
#describe_principal_mapping(params = {}) ⇒ Types::DescribePrincipalMappingResponse
Describes the processing of ‘PUT` and `DELETE` actions for mapping users to their groups. This includes information on the status of actions currently processing or yet to be processed, when actions were last updated, when actions were received by Amazon Kendra, the latest action that should process and apply after other actions, and useful error messages if an action could not be processed.
‘DescribePrincipalMapping` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
3820 3821 3822 3823 |
# File 'lib/aws-sdk-kendra/client.rb', line 3820 def describe_principal_mapping(params = {}, = {}) req = build_request(:describe_principal_mapping, params) req.send_request() end |
#describe_query_suggestions_block_list(params = {}) ⇒ Types::DescribeQuerySuggestionsBlockListResponse
Gets information about a block list used for query suggestions for an index.
This is used to check the current settings that are applied to a block list.
‘DescribeQuerySuggestionsBlockList` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
3882 3883 3884 3885 |
# File 'lib/aws-sdk-kendra/client.rb', line 3882 def describe_query_suggestions_block_list(params = {}, = {}) req = build_request(:describe_query_suggestions_block_list, params) req.send_request() end |
#describe_query_suggestions_config(params = {}) ⇒ Types::DescribeQuerySuggestionsConfigResponse
Gets information on the settings of query suggestions for an index.
This is used to check the current settings applied to query suggestions.
‘DescribeQuerySuggestionsConfig` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
3938 3939 3940 3941 |
# File 'lib/aws-sdk-kendra/client.rb', line 3938 def describe_query_suggestions_config(params = {}, = {}) req = build_request(:describe_query_suggestions_config, params) req.send_request() end |
#describe_thesaurus(params = {}) ⇒ Types::DescribeThesaurusResponse
Gets information about an Amazon Kendra thesaurus.
3995 3996 3997 3998 |
# File 'lib/aws-sdk-kendra/client.rb', line 3995 def describe_thesaurus(params = {}, = {}) req = build_request(:describe_thesaurus, params) req.send_request() end |
#disassociate_entities_from_experience(params = {}) ⇒ Types::DisassociateEntitiesFromExperienceResponse
Prevents users or groups in your IAM Identity Center identity source from accessing your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
4046 4047 4048 4049 |
# File 'lib/aws-sdk-kendra/client.rb', line 4046 def disassociate_entities_from_experience(params = {}, = {}) req = build_request(:disassociate_entities_from_experience, params) req.send_request() end |
#disassociate_personas_from_entities(params = {}) ⇒ Types::DisassociatePersonasFromEntitiesResponse
Removes the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
4094 4095 4096 4097 |
# File 'lib/aws-sdk-kendra/client.rb', line 4094 def disassociate_personas_from_entities(params = {}, = {}) req = build_request(:disassociate_personas_from_entities, params) req.send_request() end |
#get_query_suggestions(params = {}) ⇒ Types::GetQuerySuggestionsResponse
Fetches the queries that are suggested to your users.
‘GetQuerySuggestions` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
4271 4272 4273 4274 |
# File 'lib/aws-sdk-kendra/client.rb', line 4271 def get_query_suggestions(params = {}, = {}) req = build_request(:get_query_suggestions, params) req.send_request() end |
#get_snapshots(params = {}) ⇒ Types::GetSnapshotsResponse
Retrieves search metrics data. The data provides a snapshot of how your users interact with your search application and how effective the application is.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4360 4361 4362 4363 |
# File 'lib/aws-sdk-kendra/client.rb', line 4360 def get_snapshots(params = {}, = {}) req = build_request(:get_snapshots, params) req.send_request() end |
#list_access_control_configurations(params = {}) ⇒ Types::ListAccessControlConfigurationsResponse
Lists one or more access control configurations for an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4407 4408 4409 4410 |
# File 'lib/aws-sdk-kendra/client.rb', line 4407 def list_access_control_configurations(params = {}, = {}) req = build_request(:list_access_control_configurations, params) req.send_request() end |
#list_data_source_sync_jobs(params = {}) ⇒ Types::ListDataSourceSyncJobsResponse
Gets statistics about synchronizing a data source connector.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4480 4481 4482 4483 |
# File 'lib/aws-sdk-kendra/client.rb', line 4480 def list_data_source_sync_jobs(params = {}, = {}) req = build_request(:list_data_source_sync_jobs, params) req.send_request() end |
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists the data source connectors that you have created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4531 4532 4533 4534 |
# File 'lib/aws-sdk-kendra/client.rb', line 4531 def list_data_sources(params = {}, = {}) req = build_request(:list_data_sources, params) req.send_request() end |
#list_entity_personas(params = {}) ⇒ Types::ListEntityPersonasResponse
Lists specific permissions of users and groups with access to your Amazon Kendra experience.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4583 4584 4585 4586 |
# File 'lib/aws-sdk-kendra/client.rb', line 4583 def list_entity_personas(params = {}, = {}) req = build_request(:list_entity_personas, params) req.send_request() end |
#list_experience_entities(params = {}) ⇒ Types::ListExperienceEntitiesResponse
Lists users or groups in your IAM Identity Center identity source that are granted access to your Amazon Kendra experience. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4641 4642 4643 4644 |
# File 'lib/aws-sdk-kendra/client.rb', line 4641 def list_experience_entities(params = {}, = {}) req = build_request(:list_experience_entities, params) req.send_request() end |
#list_experiences(params = {}) ⇒ Types::ListExperiencesResponse
Lists one or more Amazon Kendra experiences. You can create an Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4698 4699 4700 4701 |
# File 'lib/aws-sdk-kendra/client.rb', line 4698 def list_experiences(params = {}, = {}) req = build_request(:list_experiences, params) req.send_request() end |
#list_faqs(params = {}) ⇒ Types::ListFaqsResponse
Gets a list of FAQs associated with an index.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4749 4750 4751 4752 |
# File 'lib/aws-sdk-kendra/client.rb', line 4749 def list_faqs(params = {}, = {}) req = build_request(:list_faqs, params) req.send_request() end |
#list_featured_results_sets(params = {}) ⇒ Types::ListFeaturedResultsSetsResponse
Lists all your sets of featured results for a given index. Features results are placed above all other results for certain queries. If there’s an exact match of a query, then one or more specific documents are featured in the search results.
4797 4798 4799 4800 |
# File 'lib/aws-sdk-kendra/client.rb', line 4797 def list_featured_results_sets(params = {}, = {}) req = build_request(:list_featured_results_sets, params) req.send_request() end |
#list_groups_older_than_ordering_id(params = {}) ⇒ Types::ListGroupsOlderThanOrderingIdResponse
Provides a list of groups that are mapped to users before a given ordering or timestamp identifier.
‘ListGroupsOlderThanOrderingId` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4859 4860 4861 4862 |
# File 'lib/aws-sdk-kendra/client.rb', line 4859 def list_groups_older_than_ordering_id(params = {}, = {}) req = build_request(:list_groups_older_than_ordering_id, params) req.send_request() end |
#list_indices(params = {}) ⇒ Types::ListIndicesResponse
Lists the Amazon Kendra indexes that you created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4903 4904 4905 4906 |
# File 'lib/aws-sdk-kendra/client.rb', line 4903 def list_indices(params = {}, = {}) req = build_request(:list_indices, params) req.send_request() end |
#list_query_suggestions_block_lists(params = {}) ⇒ Types::ListQuerySuggestionsBlockListsResponse
Lists the block lists used for query suggestions for an index.
For information on the current quota limits for block lists, see [Quotas for Amazon Kendra].
‘ListQuerySuggestionsBlockLists` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
[1]: docs.aws.amazon.com/kendra/latest/dg/quotas.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4970 4971 4972 4973 |
# File 'lib/aws-sdk-kendra/client.rb', line 4970 def list_query_suggestions_block_lists(params = {}, = {}) req = build_request(:list_query_suggestions_block_lists, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags associated with a resource. Indexes, FAQs, data sources, and other resources can have tags associated with them.
5010 5011 5012 5013 |
# File 'lib/aws-sdk-kendra/client.rb', line 5010 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_thesauri(params = {}) ⇒ Types::ListThesauriResponse
Lists the thesauri for an index.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5058 5059 5060 5061 |
# File 'lib/aws-sdk-kendra/client.rb', line 5058 def list_thesauri(params = {}, = {}) req = build_request(:list_thesauri, params) req.send_request() end |
#put_principal_mapping(params = {}) ⇒ Struct
Maps users to their groups so that you only need to provide the user ID when you issue the query.
You can also map sub groups to groups. For example, the group “Company Intellectual Property Teams” includes sub groups “Research” and “Engineering”. These sub groups include their own list of users or people who work in these teams. Only users who work in research and engineering, and therefore belong in the intellectual property group, can see top-secret company documents in their search results.
This is useful for user context filtering, where search results are filtered based on the user or their group access to documents. For more information, see [Filtering on user context].
If more than five ‘PUT` actions for a group are currently processing, a validation exception is thrown.
[1]: docs.aws.amazon.com/kendra/latest/dg/user-context-filter.html
5176 5177 5178 5179 |
# File 'lib/aws-sdk-kendra/client.rb', line 5176 def put_principal_mapping(params = {}, = {}) req = build_request(:put_principal_mapping, params) req.send_request() end |
#query(params = {}) ⇒ Types::QueryResult
Searches an index given an input query.
<note markdown=“1”> If you are working with large language models (LLMs) or implementing retrieval augmented generation (RAG) systems, you can use Amazon Kendra’s [Retrieve] API, which can return longer semantically relevant passages. We recommend using the ‘Retrieve` API instead of filing a service limit increase to increase the `Query` API document excerpt length.
</note>
You can configure boosting or relevance tuning at the query level to override boosting at the index level, filter based on document fields/attributes and faceted search, and filter based on the user or their group access to documents. You can also include certain fields in the response that might provide useful additional information.
A query response contains three types of results.
-
Relevant suggested answers. The answers can be either a text excerpt or table excerpt. The answer can be highlighted in the excerpt.
-
Matching FAQs or questions-answer from your FAQ file.
-
Relevant documents. This result type includes an excerpt of the document with the document title. The searched terms can be highlighted in the excerpt.
You can specify that the query return only one type of result using the ‘QueryResultTypeFilter` parameter. Each query returns the 100 most relevant results. If you filter result type to only question-answers, a maximum of four results are returned. If you filter result type to only answers, a maximum of three results are returned.
If you’re using an Amazon Kendra Gen AI Enterprise Edition index, you can only use ‘ATTRIBUTE_FILTER` to filter search results by user context. If you’re using an Amazon Kendra Gen AI Enterprise Edition index and you try to use ‘USER_TOKEN` to configure user context policy, Amazon Kendra returns a `ValidationException` error.
[1]: docs.aws.amazon.com/kendra/latest/APIReference/API_Retrieve.html
5631 5632 5633 5634 |
# File 'lib/aws-sdk-kendra/client.rb', line 5631 def query(params = {}, = {}) req = build_request(:query, params) req.send_request() end |
#retrieve(params = {}) ⇒ Types::RetrieveResult
Retrieves relevant passages or text excerpts given an input query.
This API is similar to the [Query] API. However, by default, the ‘Query` API only returns excerpt passages of up to 100 token words. With the `Retrieve` API, you can retrieve longer passages of up to 200 token words and up to 100 semantically relevant passages. This doesn’t include question-answer or FAQ type responses from your index. The passages are text excerpts that can be semantically extracted from multiple documents and multiple parts of the same document. If in extreme cases your documents produce zero passages using the ‘Retrieve` API, you can alternatively use the `Query` API and its types of responses.
You can also do the following:
-
Override boosting at the index level
-
Filter based on document fields or attributes
-
Filter based on the user or their group access to documents
-
View the confidence score bucket for a retrieved passage result. The confidence bucket provides a relative ranking that indicates how confident Amazon Kendra is that the response is relevant to the query.
<note markdown=“1”> Confidence score buckets are currently available only for English.
</note>
You can also include certain fields in the response that might provide useful additional information.
The ‘Retrieve` API shares the number of [query capacity units] that you set for your index. For more information on what’s included in a single capacity unit and the default base capacity for an index, see [Adjusting capacity].
If you’re using an Amazon Kendra Gen AI Enterprise Edition index, you can only use ‘ATTRIBUTE_FILTER` to filter search results by user context. If you’re using an Amazon Kendra Gen AI Enterprise Edition index and you try to use ‘USER_TOKEN` to configure user context policy, Amazon Kendra returns a `ValidationException` error.
[1]: docs.aws.amazon.com/kendra/latest/APIReference/API_Query.html [2]: docs.aws.amazon.com/kendra/latest/APIReference/API_CapacityUnitsConfiguration.html [3]: docs.aws.amazon.com/kendra/latest/dg/adjusting-capacity.html
5891 5892 5893 5894 |
# File 'lib/aws-sdk-kendra/client.rb', line 5891 def retrieve(params = {}, = {}) req = build_request(:retrieve, params) req.send_request() end |
#start_data_source_sync_job(params = {}) ⇒ Types::StartDataSourceSyncJobResponse
Starts a synchronization job for a data source connector. If a synchronization job is already in progress, Amazon Kendra returns a ‘ResourceInUseException` exception.
Re-syncing your data source with your index after modifying, adding, or deleting documents from your data source respository could take up to an hour or more, depending on the number of documents to sync.
5929 5930 5931 5932 |
# File 'lib/aws-sdk-kendra/client.rb', line 5929 def start_data_source_sync_job(params = {}, = {}) req = build_request(:start_data_source_sync_job, params) req.send_request() end |
#stop_data_source_sync_job(params = {}) ⇒ Struct
Stops a synchronization job that is currently running. You can’t stop a scheduled synchronization job.
5957 5958 5959 5960 |
# File 'lib/aws-sdk-kendra/client.rb', line 5957 def stop_data_source_sync_job(params = {}, = {}) req = build_request(:stop_data_source_sync_job, params) req.send_request() end |
#submit_feedback(params = {}) ⇒ Struct
Enables you to provide feedback to Amazon Kendra to improve the performance of your index.
‘SubmitFeedback` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
6008 6009 6010 6011 |
# File 'lib/aws-sdk-kendra/client.rb', line 6008 def submit_feedback(params = {}, = {}) req = build_request(:submit_feedback, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tag to the specified index, FAQ, data source, or other resource. If the tag already exists, the existing value is replaced with the new value.
6052 6053 6054 6055 |
# File 'lib/aws-sdk-kendra/client.rb', line 6052 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from an index, FAQ, data source, or other resource.
6089 6090 6091 6092 |
# File 'lib/aws-sdk-kendra/client.rb', line 6089 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_access_control_configuration(params = {}) ⇒ Struct
Updates an access control configuration for your documents in an index. This includes user and group access information for your documents. This is useful for user context filtering, where search results are filtered based on the user or their group access to documents.
You can update an access control configuration you created without indexing all of your documents again. For example, your index contains top-secret company documents that only certain employees or users should access. You created an ‘allow’ access control configuration for one user who recently joined the ‘top-secret’ team, switching from a team with ‘deny’ access to top-secret documents. However, the user suddenly returns to their previous team and should no longer have access to top secret documents. You can update the access control configuration to re-configure access control for your documents as circumstances change.
You call the [BatchPutDocument] API to apply the updated access control configuration, with the ‘AccessControlConfigurationId` included in the [Document] object. If you use an S3 bucket as a data source, you synchronize your data source to apply the `AccessControlConfigurationId` in the `.metadata.json` file. Amazon Kendra currently only supports access control configuration for S3 data sources and documents indexed using the `BatchPutDocument` API.
You can’t configure access control using ‘CreateAccessControlConfiguration` for an Amazon Kendra Gen AI Enterprise Edition index. Amazon Kendra will return a `ValidationException` error for a `Gen_AI_ENTERPRISE_EDITION` index.
[1]: docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html [2]: docs.aws.amazon.com/kendra/latest/dg/API_Document.html
6190 6191 6192 6193 |
# File 'lib/aws-sdk-kendra/client.rb', line 6190 def update_access_control_configuration(params = {}, = {}) req = build_request(:update_access_control_configuration, params) req.send_request() end |
#update_data_source(params = {}) ⇒ Struct
Updates an Amazon Kendra data source connector.
6966 6967 6968 6969 |
# File 'lib/aws-sdk-kendra/client.rb', line 6966 def update_data_source(params = {}, = {}) req = build_request(:update_data_source, params) req.send_request() end |
#update_experience(params = {}) ⇒ Struct
Updates your Amazon Kendra experience such as a search application. For more information on creating a search application experience, see [Building a search experience with no code].
[1]: docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html
7031 7032 7033 7034 |
# File 'lib/aws-sdk-kendra/client.rb', line 7031 def update_experience(params = {}, = {}) req = build_request(:update_experience, params) req.send_request() end |
#update_featured_results_set(params = {}) ⇒ Types::UpdateFeaturedResultsSetResponse
Updates a set of featured results. Features results are placed above all other results for certain queries. You map specific queries to specific documents for featuring in the results. If a query contains an exact match of a query, then one or more specific documents are featured in the search results.
7115 7116 7117 7118 |
# File 'lib/aws-sdk-kendra/client.rb', line 7115 def update_featured_results_set(params = {}, = {}) req = build_request(:update_featured_results_set, params) req.send_request() end |
#update_index(params = {}) ⇒ Struct
Updates an Amazon Kendra index.
7240 7241 7242 7243 |
# File 'lib/aws-sdk-kendra/client.rb', line 7240 def update_index(params = {}, = {}) req = build_request(:update_index, params) req.send_request() end |
#update_query_suggestions_block_list(params = {}) ⇒ Struct
Updates a block list used for query suggestions for an index.
Updates to a block list might not take effect right away. Amazon Kendra needs to refresh the entire suggestions list to apply any updates to the block list. Other changes not related to the block list apply immediately.
If a block list is updating, then you need to wait for the first update to finish before submitting another update.
Amazon Kendra supports partial updates, so you only need to provide the fields you want to update.
‘UpdateQuerySuggestionsBlockList` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
7310 7311 7312 7313 |
# File 'lib/aws-sdk-kendra/client.rb', line 7310 def update_query_suggestions_block_list(params = {}, = {}) req = build_request(:update_query_suggestions_block_list, params) req.send_request() end |
#update_query_suggestions_config(params = {}) ⇒ Struct
Updates the settings of query suggestions for an index.
Amazon Kendra supports partial updates, so you only need to provide the fields you want to update.
If an update is currently processing, you need to wait for the update to finish before making another update.
Updates to query suggestions settings might not take effect right away. The time for your updated settings to take effect depends on the updates made and the number of search queries in your index.
You can still enable/disable query suggestions at any time.
‘UpdateQuerySuggestionsConfig` is currently not supported in the Amazon Web Services GovCloud (US-West) region.
7419 7420 7421 7422 |
# File 'lib/aws-sdk-kendra/client.rb', line 7419 def update_query_suggestions_config(params = {}, = {}) req = build_request(:update_query_suggestions_config, params) req.send_request() end |
#update_thesaurus(params = {}) ⇒ Struct
Updates a thesaurus for an index.
7465 7466 7467 7468 |
# File 'lib/aws-sdk-kendra/client.rb', line 7465 def update_thesaurus(params = {}, = {}) req = build_request(:update_thesaurus, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7494 7495 7496 |
# File 'lib/aws-sdk-kendra/client.rb', line 7494 def waiter_names [] end |