Class: Aws::Kendra::Types::BatchPutDocumentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kendra::Types::BatchPutDocumentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kendra/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_document_enrichment_configuration ⇒ Types::CustomDocumentEnrichmentConfiguration
Configuration information for altering your document metadata and content during the document ingestion process when you use the
BatchPutDocumentAPI. -
#documents ⇒ Array<Types::Document>
One or more documents to add to the index.
-
#index_id ⇒ String
The identifier of the index to add the documents to.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role with permission to access your S3 bucket.
Instance Attribute Details
#custom_document_enrichment_configuration ⇒ Types::CustomDocumentEnrichmentConfiguration
Configuration information for altering your document metadata and content during the document ingestion process when you use the BatchPutDocument API.
For more information on how to create, modify and delete document metadata, or make other content alterations when you ingest documents into Amazon Kendra, see [Customizing document metadata during the ingestion process].
[1]: docs.aws.amazon.com/kendra/latest/dg/custom-document-enrichment.html
918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kendra/types.rb', line 918 class BatchPutDocumentRequest < Struct.new( :index_id, :role_arn, :documents, :custom_document_enrichment_configuration) SENSITIVE = [] include Aws::Structure end |
#documents ⇒ Array<Types::Document>
One or more documents to add to the index.
Documents have the following file size limits.
-
50 MB total size for any file
-
5 MB extracted text for any file
For more information, see [Quotas].
918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kendra/types.rb', line 918 class BatchPutDocumentRequest < Struct.new( :index_id, :role_arn, :documents, :custom_document_enrichment_configuration) SENSITIVE = [] include Aws::Structure end |
#index_id ⇒ String
The identifier of the index to add the documents to. You need to create the index first using the CreateIndex API.
918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kendra/types.rb', line 918 class BatchPutDocumentRequest < Struct.new( :index_id, :role_arn, :documents, :custom_document_enrichment_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role with permission to access your S3 bucket. For more information, see [IAM access roles for Amazon Kendra].
918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kendra/types.rb', line 918 class BatchPutDocumentRequest < Struct.new( :index_id, :role_arn, :documents, :custom_document_enrichment_configuration) SENSITIVE = [] include Aws::Structure end |