Class: Aws::Kendra::Types::ConfluenceBlogConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kendra/types.rb

Overview

Configuration of blog settings for the Confluence data source. Blogs are always indexed unless filtered from the index by the ExclusionPatterns or InclusionPatterns fields in the ConfluenceConfiguration object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blog_field_mappingsArray<Types::ConfluenceBlogToIndexFieldMapping>

Maps attributes or field names of Confluence blogs to Amazon Kendra index field names. To create custom fields, use the UpdateIndex API before you map to Confluence fields. For more information, see [Mapping data source fields]. The Confluence data source field names must exist in your Confluence custom metadata.

If you specify the BlogFieldMappings parameter, you must specify at least one field mapping.

[1]: docs.aws.amazon.com/kendra/latest/dg/field-mapping.html



1461
1462
1463
1464
1465
# File 'lib/aws-sdk-kendra/types.rb', line 1461

class ConfluenceBlogConfiguration < Struct.new(
  :blog_field_mappings)
  SENSITIVE = []
  include Aws::Structure
end