Class: Aws::Kendra::Types::ConfluenceSpaceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kendra::Types::ConfluenceSpaceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kendra/types.rb
Overview
Configuration information for indexing Confluence spaces.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crawl_archived_spaces ⇒ Boolean
TRUEto index archived spaces. -
#crawl_personal_spaces ⇒ Boolean
TRUEto index personal spaces. -
#exclude_spaces ⇒ Array<String>
A list of space keys of Confluence spaces.
-
#include_spaces ⇒ Array<String>
A list of space keys for Confluence spaces.
-
#space_field_mappings ⇒ Array<Types::ConfluenceSpaceToIndexFieldMapping>
Maps attributes or field names of Confluence spaces to Amazon Kendra index field names.
Instance Attribute Details
#crawl_archived_spaces ⇒ Boolean
TRUE to index archived spaces.
1737 1738 1739 1740 1741 1742 1743 1744 1745 |
# File 'lib/aws-sdk-kendra/types.rb', line 1737 class ConfluenceSpaceConfiguration < Struct.new( :crawl_personal_spaces, :crawl_archived_spaces, :include_spaces, :exclude_spaces, :space_field_mappings) SENSITIVE = [] include Aws::Structure end |
#crawl_personal_spaces ⇒ Boolean
TRUE to index personal spaces. You can add restrictions to items in personal spaces. If personal spaces are indexed, queries without user context information may return restricted items from a personal space in their results. For more information, see [Filtering on user context].
[1]: docs.aws.amazon.com/kendra/latest/dg/user-context-filter.html
1737 1738 1739 1740 1741 1742 1743 1744 1745 |
# File 'lib/aws-sdk-kendra/types.rb', line 1737 class ConfluenceSpaceConfiguration < Struct.new( :crawl_personal_spaces, :crawl_archived_spaces, :include_spaces, :exclude_spaces, :space_field_mappings) SENSITIVE = [] include Aws::Structure end |
#exclude_spaces ⇒ Array<String>
A list of space keys of Confluence spaces. If you include a key, the blogs, documents, and attachments in the space are not indexed. If a space is in both the ExcludeSpaces and the IncludeSpaces list, the space is excluded.
1737 1738 1739 1740 1741 1742 1743 1744 1745 |
# File 'lib/aws-sdk-kendra/types.rb', line 1737 class ConfluenceSpaceConfiguration < Struct.new( :crawl_personal_spaces, :crawl_archived_spaces, :include_spaces, :exclude_spaces, :space_field_mappings) SENSITIVE = [] include Aws::Structure end |
#include_spaces ⇒ Array<String>
A list of space keys for Confluence spaces. If you include a key, the blogs, documents, and attachments in the space are indexed. Spaces that aren’t in the list aren’t indexed. A space in the list must exist. Otherwise, Amazon Kendra logs an error when the data source is synchronized. If a space is in both the IncludeSpaces and the ExcludeSpaces list, the space is excluded.
1737 1738 1739 1740 1741 1742 1743 1744 1745 |
# File 'lib/aws-sdk-kendra/types.rb', line 1737 class ConfluenceSpaceConfiguration < Struct.new( :crawl_personal_spaces, :crawl_archived_spaces, :include_spaces, :exclude_spaces, :space_field_mappings) SENSITIVE = [] include Aws::Structure end |
#space_field_mappings ⇒ Array<Types::ConfluenceSpaceToIndexFieldMapping>
Maps attributes or field names of Confluence spaces to Amazon Kendra index field names. To create custom fields, use the UpdateIndex API before you map to Confluence fields. For more information, see [Mapping data source fields]. The Confluence data source field names must exist in your Confluence custom metadata.
If you specify the SpaceFieldMappings parameter, you must specify at least one field mapping.
[1]: docs.aws.amazon.com/kendra/latest/dg/field-mapping.html
1737 1738 1739 1740 1741 1742 1743 1744 1745 |
# File 'lib/aws-sdk-kendra/types.rb', line 1737 class ConfluenceSpaceConfiguration < Struct.new( :crawl_personal_spaces, :crawl_archived_spaces, :include_spaces, :exclude_spaces, :space_field_mappings) SENSITIVE = [] include Aws::Structure end |