Class: Aws::Kendra::Types::CreateQuerySuggestionsBlockListRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kendra/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A token that you provide to identify the request to create a query suggestions block list.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-kendra/types.rb', line 2548

class CreateQuerySuggestionsBlockListRequest < Struct.new(
  :index_id,
  :name,
  :description,
  :source_s3_path,
  :client_token,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the block list.

For example, the description "List of all offensive words that can appear in user queries and need to be blocked from suggestions."

Returns:

  • (String)


2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-kendra/types.rb', line 2548

class CreateQuerySuggestionsBlockListRequest < Struct.new(
  :index_id,
  :name,
  :description,
  :source_s3_path,
  :client_token,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#index_idString

The identifier of the index you want to create a query suggestions block list for.

Returns:

  • (String)


2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-kendra/types.rb', line 2548

class CreateQuerySuggestionsBlockListRequest < Struct.new(
  :index_id,
  :name,
  :description,
  :source_s3_path,
  :client_token,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the block list.

For example, the name 'offensive-words', which includes all offensive words that could appear in user queries and need to be blocked from suggestions.

Returns:

  • (String)


2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-kendra/types.rb', line 2548

class CreateQuerySuggestionsBlockListRequest < Struct.new(
  :index_id,
  :name,
  :description,
  :source_s3_path,
  :client_token,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role with permission to access your S3 bucket that contains the block list text file. For more information, see IAM access roles for Amazon Kendra.

Returns:

  • (String)


2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-kendra/types.rb', line 2548

class CreateQuerySuggestionsBlockListRequest < Struct.new(
  :index_id,
  :name,
  :description,
  :source_s3_path,
  :client_token,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#source_s3_pathTypes::S3Path

The S3 path to your block list text file in your S3 bucket.

Each block word or phrase should be on a separate line in a text file.

For information on the current quota limits for block lists, see Quotas for Amazon Kendra.

Returns:



2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-kendra/types.rb', line 2548

class CreateQuerySuggestionsBlockListRequest < Struct.new(
  :index_id,
  :name,
  :description,
  :source_s3_path,
  :client_token,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of key-value pairs that identify or categorize the block list. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.

Returns:



2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-kendra/types.rb', line 2548

class CreateQuerySuggestionsBlockListRequest < Struct.new(
  :index_id,
  :name,
  :description,
  :source_s3_path,
  :client_token,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end