Class: Aws::Kendra::Types::DataSourceSyncJobMetrics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kendra/types.rb

Overview

Maps a batch delete document request to a specific data source sync job. This is optional and should only be supplied when documents are deleted by a data source connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#documents_addedString

The number of documents added from the data source up to now in the data source sync.



3103
3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-kendra/types.rb', line 3103

class DataSourceSyncJobMetrics < Struct.new(
  :documents_added,
  :documents_modified,
  :documents_deleted,
  :documents_failed,
  :documents_scanned)
  SENSITIVE = []
  include Aws::Structure
end

#documents_deletedString

The number of documents deleted from the data source up to now in the data source sync run.



3103
3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-kendra/types.rb', line 3103

class DataSourceSyncJobMetrics < Struct.new(
  :documents_added,
  :documents_modified,
  :documents_deleted,
  :documents_failed,
  :documents_scanned)
  SENSITIVE = []
  include Aws::Structure
end

#documents_failedString

The number of documents that failed to sync from the data source up to now in the data source sync run.



3103
3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-kendra/types.rb', line 3103

class DataSourceSyncJobMetrics < Struct.new(
  :documents_added,
  :documents_modified,
  :documents_deleted,
  :documents_failed,
  :documents_scanned)
  SENSITIVE = []
  include Aws::Structure
end

#documents_modifiedString

The number of documents modified in the data source up to now in the data source sync run.



3103
3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-kendra/types.rb', line 3103

class DataSourceSyncJobMetrics < Struct.new(
  :documents_added,
  :documents_modified,
  :documents_deleted,
  :documents_failed,
  :documents_scanned)
  SENSITIVE = []
  include Aws::Structure
end

#documents_scannedString

The current number of documents crawled by the current sync job in the data source.



3103
3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-kendra/types.rb', line 3103

class DataSourceSyncJobMetrics < Struct.new(
  :documents_added,
  :documents_modified,
  :documents_deleted,
  :documents_failed,
  :documents_scanned)
  SENSITIVE = []
  include Aws::Structure
end