Class: Aws::Kendra::Types::DocumentInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kendra::Types::DocumentInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kendra/types.rb
Overview
Identifies a document for which to retrieve status information
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Types::DocumentAttribute>
Attributes that identify a specific version of a document to check.
-
#document_id ⇒ String
The identifier of the document.
Instance Attribute Details
#attributes ⇒ Array<Types::DocumentAttribute>
Attributes that identify a specific version of a document to check.
The only valid attributes are:
-
version
-
datasourceId
-
jobExecutionId
The attributes follow these rules:
-
dataSourceIdandjobExecutionIdmust be used together. -
versionis ignored ifdataSourceIdandjobExecutionIdare not provided. -
If
dataSourceIdandjobExecutionIdare provided, butversionis not, the version defaults to "0".
4777 4778 4779 4780 4781 4782 |
# File 'lib/aws-sdk-kendra/types.rb', line 4777 class DocumentInfo < Struct.new( :document_id, :attributes) SENSITIVE = [] include Aws::Structure end |
#document_id ⇒ String
The identifier of the document.
4777 4778 4779 4780 4781 4782 |
# File 'lib/aws-sdk-kendra/types.rb', line 4777 class DocumentInfo < Struct.new( :document_id, :attributes) SENSITIVE = [] include Aws::Structure end |