Class: Aws::Kendra::Types::WorkDocsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kendra::Types::WorkDocsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kendra/types.rb
Overview
Provides the configuration information to connect to WorkDocs as your data source.
WorkDocs connector is available in Oregon, North Virginia, Sydney, Singapore and Ireland regions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crawl_comments ⇒ Boolean
TRUEto include comments on documents in your index. -
#exclusion_patterns ⇒ Array<String>
A list of regular expression patterns to exclude certain files in your WorkDocs site repository.
-
#field_mappings ⇒ Array<Types::DataSourceToIndexFieldMapping>
A list of
DataSourceToIndexFieldMappingobjects that map WorkDocs data source attributes or field names to Amazon Kendra index field names. -
#inclusion_patterns ⇒ Array<String>
A list of regular expression patterns to include certain files in your WorkDocs site repository.
-
#organization_id ⇒ String
The identifier of the directory corresponding to your WorkDocs site repository.
-
#use_change_log ⇒ Boolean
TRUEto use the WorkDocs change log to determine which documents require updating in the index.
Instance Attribute Details
#crawl_comments ⇒ Boolean
TRUE to include comments on documents in your index. Including
comments in your index means each comment is a document that can be
searched on.
The default is set to FALSE.
11442 11443 11444 11445 11446 11447 11448 11449 11450 11451 |
# File 'lib/aws-sdk-kendra/types.rb', line 11442 class WorkDocsConfiguration < Struct.new( :organization_id, :crawl_comments, :use_change_log, :inclusion_patterns, :exclusion_patterns, :field_mappings) SENSITIVE = [] include Aws::Structure end |
#exclusion_patterns ⇒ Array<String>
A list of regular expression patterns to exclude certain files in your WorkDocs site repository. Files that match the patterns are excluded from the index. Files that don’t match the patterns are included in the index. If a file matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the file isn't included in the index.
11442 11443 11444 11445 11446 11447 11448 11449 11450 11451 |
# File 'lib/aws-sdk-kendra/types.rb', line 11442 class WorkDocsConfiguration < Struct.new( :organization_id, :crawl_comments, :use_change_log, :inclusion_patterns, :exclusion_patterns, :field_mappings) SENSITIVE = [] include Aws::Structure end |
#field_mappings ⇒ Array<Types::DataSourceToIndexFieldMapping>
A list of DataSourceToIndexFieldMapping objects that map WorkDocs
data source attributes or field names to Amazon Kendra index field
names. To create custom fields, use the UpdateIndex API before you
map to WorkDocs fields. For more information, see Mapping data
source fields. The WorkDocs data source field names must exist
in your WorkDocs custom metadata.
11442 11443 11444 11445 11446 11447 11448 11449 11450 11451 |
# File 'lib/aws-sdk-kendra/types.rb', line 11442 class WorkDocsConfiguration < Struct.new( :organization_id, :crawl_comments, :use_change_log, :inclusion_patterns, :exclusion_patterns, :field_mappings) SENSITIVE = [] include Aws::Structure end |
#inclusion_patterns ⇒ Array<String>
A list of regular expression patterns to include certain files in your WorkDocs site repository. Files that match the patterns are included in the index. Files that don't match the patterns are excluded from the index. If a file matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the file isn't included in the index.
11442 11443 11444 11445 11446 11447 11448 11449 11450 11451 |
# File 'lib/aws-sdk-kendra/types.rb', line 11442 class WorkDocsConfiguration < Struct.new( :organization_id, :crawl_comments, :use_change_log, :inclusion_patterns, :exclusion_patterns, :field_mappings) SENSITIVE = [] include Aws::Structure end |
#organization_id ⇒ String
The identifier of the directory corresponding to your WorkDocs site repository.
You can find the organization ID in the Directory Service by going to Active Directory, then Directories. Your WorkDocs site directory has an ID, which is the organization ID. You can also set up a new WorkDocs directory in the Directory Service console and enable a WorkDocs site for the directory in the WorkDocs console.
11442 11443 11444 11445 11446 11447 11448 11449 11450 11451 |
# File 'lib/aws-sdk-kendra/types.rb', line 11442 class WorkDocsConfiguration < Struct.new( :organization_id, :crawl_comments, :use_change_log, :inclusion_patterns, :exclusion_patterns, :field_mappings) SENSITIVE = [] include Aws::Structure end |
#use_change_log ⇒ Boolean
TRUE to use the WorkDocs change log to determine which documents
require updating in the index. Depending on the change log's size,
it may take longer for Amazon Kendra to use the change log than to
scan all of your documents in WorkDocs.
11442 11443 11444 11445 11446 11447 11448 11449 11450 11451 |
# File 'lib/aws-sdk-kendra/types.rb', line 11442 class WorkDocsConfiguration < Struct.new( :organization_id, :crawl_comments, :use_change_log, :inclusion_patterns, :exclusion_patterns, :field_mappings) SENSITIVE = [] include Aws::Structure end |